#[repr(u8)]pub enum SmctrlClkSel {
IPBUS = 0,
EXT_CLK = 1,
AUX_CLK = 2,
_RESERVED_3 = 3,
}Variants
IPBUS = 0
The IPBus clock is used as the clock for the local prescaler and counter.
EXT_CLK = 1
EXT_CLK is used as the clock for the local prescaler and counter.
AUX_CLK = 2
Submodule 0’s clock (AUX_CLK) is used as the source clock for the local prescaler and counter. This setting should not be used in submodule 0 as it forces the clock to logic 0.
_RESERVED_3 = 3
Implementations
Sourceimpl SmctrlClkSel
impl SmctrlClkSel