#[repr(u8)]pub enum SmctrlLdmod {
NEXT_PWM_RELOAD = 0,
MTCTRL_LDOK_SET = 1,
}Variants
NEXT_PWM_RELOAD = 0
Buffered registers of this submodule are loaded and take effect at the next PWM reload if MCTRL[LDOK] is set.
MTCTRL_LDOK_SET = 1
Buffered registers of this submodule are loaded and take effect immediately upon MCTRL[LDOK] being set. In this case, it is not necessary to set CTRL[FULL] or CTRL[HALF].
Implementations
Sourceimpl SmctrlLdmod
impl SmctrlLdmod