#[repr(u8)]pub enum SmtctrlTrgfrq {
EVERYPWM = 0,
FINALPWM = 1,
}Variants
EVERYPWM = 0
Trigger outputs are generated during every PWM period even if the PWM is not reloaded every period due to CTRL[LDFQ] being non-zero.
FINALPWM = 1
Trigger outputs are generated only during the final PWM period prior to a reload opportunity when the PWM is not reloaded every period due to CTRL[LDFQ] being non-zero.
Implementations
Sourceimpl SmtctrlTrgfrq
impl SmtctrlTrgfrq